@@ -424,11 +424,11 @@ class Package(object):
             board = get_specified_board()
             if board:
                 self.hw_info.board_name = board
-        text = self.hw_info.check(self.type)
+        # text = self.hw_info.check(self.type)
 
-        if text:
-            logger.error(self.name + ' ' + text)
-            exit(-1)
+        # if text:
+        #     logger.error(self.name + ' ' + text)
+        #     exit(-1)
 
     def show(self):
         for k, v in self.__dict__.items():
@@ -457,7 +457,7 @@ class Package(object):
 # depends:                                 # <可选项> 该组件依赖其他的组件，合理的依赖才能保证组件能编译、使用
 #   - minilibc: 'v7.2.0'
 #   - aos: 'v7.2.0 ? <ENABLE_AOS>'
-{depends}{hw_info}
+{depends}{supported_boards}{hw_info}
 ## 第四部分：编译连接信息
 # build_config:                            # <可选项> 编译配置项
 #   include:                               # <可选项> 编译时，影响编译器的-I 参数 ,全局有效
@@ -504,6 +504,7 @@ class Package(object):
             type=self.text_out(
                 'type', self.type, '# <必选项> 组件类型，为：solution, board, chip, arch, drv_core, drv_peripheral, drv_external_device, kernel, common, sdk, document'),
             depends=self.depends_out(),
+            supported_boards=self.supported_boards_out(),
             source_file=self.fsource_file_out(),
             install=self.install_out('install', self.install),
             export=self.install_out('export', self.export),
@@ -576,6 +577,17 @@ class Package(object):
 
         return text
 
+    def supported_boards_out(self):
+        text = ''
+        if len(self.supported_boards) > 0:
+            text = 'supported_boards:\n'
+            for d in self.supported_boards:
+                for k, v in d.items():
+                    text += '  - {}: {}\n'.format(k, v)
+                    break
+
+        return text
+
     def fsource_file_out(self):
         text = ""
         if len(self.source_file) > 0:
