@@ -270,6 +270,9 @@ class Solution:
             for component in self.components:
                 if component.type == 'chip':
                     add_defines(component)
+            for component in self.components:
+                if component.type == 'sdk':
+                    add_defines(component)
             for component in self.components:
                 if component.type == 'board':
                     add_defines(component)
@@ -291,7 +294,7 @@ class Solution:
                         self.CXXFLAGS.append(c)
                     for c in component.build_config.ldflag.split():
                         self.LINKFLAGS.append(c)
-                    
+
                     for c in component.build_config.icc_cflag.split():
                         self.ICC_CFLAGS.append(c)
                     for c in component.build_config.icc_asmflag.split():
@@ -300,7 +303,7 @@ class Solution:
                         self.ICC_CXXFLAGS.append(c)
                     for c in component.build_config.icc_ldflag.split():
                         self.ICC_LINKFLAGS.append(c)
-                    
+
                     for c in component.build_config.armcc_cflag.split():
                         self.ARMCC_CFLAGS.append(c)
                     for c in component.build_config.armcc_asmflag.split():
@@ -541,7 +544,7 @@ def riscv_cpu_id(cpu):
         return 'rv32fd_32gpr'
     elif a == 'c906':
         return 'rv64_32gpr'
-    elif a == 'c906fd' or a == 'c906v' or a == 'c910' or a == 'c910v' or a == 'c906d':
+    elif a == 'c906fd' or a == 'c906v' or a == 'c910' or a == 'c910v' or a == 'c906fdv':
         return 'rv64fd_32gpr'
     else:
         put_string("%s not support yet." % a)
