@@ -123,18 +123,20 @@ Make aos program.\n"
             if len(v) != 2:
                 put_string("Invalid format. Please config it like aos make solution@board -c config")
                 exit(-1)
-            set_specified_board(v[1])
+
             # update package.yaml of solution: set the specified board as default one
             filename = os.path.join(yoc_path, "solutions", v[0], 'package.yaml')
+
             if os.path.isfile(filename):
                 pack = Package(filename)
-                if pack.hw_info.board_name != v[1]:
-                    for d in pack.depends:
-                        if v[1] in d:
-                            pack.depends.remove(d)
-                    pack.depends.append({v[1]: "master"})
-                    pack.hw_info.board_name = v[1]
-                    pack.save(filename)
+                for d in pack.depends:
+                    if pack.hw_info.board_name in d:
+                        pack.depends.remove(d)
+                    l = str(d).replace("}","").replace("'","").split(":")
+                depend = {v[1]: l[1]}
+                pack.depends.append(depend)
+                pack.hw_info.board_name = v[1]
+                pack.save(filename)
                 # save solution and board in .config file
                 with codecs.open(config_file, 'w', 'UTF-8') as f:
                     f.write("{}: {}\n".format("solution", v[0]))
