@@ -20,7 +20,8 @@ all_toolchain_url = {
     'Win32':{
     'csky-abiv2-elf': 'https://gitee.com/alios-things/gcc-csky-abiv2-win32.git -b aos',
     'riscv64-unknown-elf': '',
-    'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-win32.git -b aos'
+    'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-win32.git -b aos',
+    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-windows.git'
     }, 
     'Linux32':{
     'csky-abiv2-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-i386-minilibc-20200407.tar.gz',
@@ -30,12 +31,14 @@ all_toolchain_url = {
     'Linux64':{
     'csky-abiv2-elf': 'https://gitee.com/alios-things/gcc-csky-abiv2-linux.git -b aos',
     'riscv64-unknown-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-x86_64-20200820.tar.gz',
-    'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-linux.git -b aos'
+    'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-linux.git -b aos',
+    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-linux.git'
     }, 
     'OSX':{
     'csky-abiv2-elf': '',
     'riscv64-unknown-elf': '',
-    'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-osx.git -b aos'
+    'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-osx.git -b aos',
+    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-osx.git'
     }
 }
 
@@ -109,6 +112,9 @@ class ToolchainYoC:
         if arch.startswith('arm-none-eabi'):
             # arm-none-eabi toolchain updated!
             path = ""
+        if arch.startswith('arm-ali-aoseabi'):
+            # arm-ali-aoseabi toolchain updated!
+            path = ""
 
         if not path:
             path = os.path.join(self.basepath, arch, "bin", arch + '-gcc')
@@ -123,6 +129,10 @@ class ToolchainYoC:
         if arch.startswith('arm-none-eabi'):
             # arm-none-eabi toolchain updated!
             path = ""
+        if arch.startswith('arm-ali-aoseabi'):
+            # arm-ali-aoseabi toolchain updated!
+            path = ""
+
         if not path:
             path = os.path.join(self.basepath, arch, "bin", arch + '-gcc')
             path = which(path)
