@@ -15,7 +15,7 @@ import re
 import platform
 import subprocess
 import chardet
-import glob
+import glob2
 import shutil
 
 try:
@@ -484,7 +484,7 @@ def get_host_os():
 def find_latest_file(src):
     latest_modified_time = 0.0
     latest_file = ""
-    for s in glob.iglob(src):
+    for s in glob2.iglob(src):
         modified_time = os.stat(s).st_mtime
         if modified_time > latest_modified_time:
             latest_modified_time = modified_time
@@ -521,26 +521,35 @@ def get_elf_bin_file(filename):
         exit(-1)
 
 def which(program, extra_path=None):
-    if get_host_os() == 'Win32' and program.endswith('.exe') == False:
-        program += '.exe'
-
     def is_exe(fpath):
         return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
+    def which_internal(program, extra_path):
+        fpath, fname = os.path.split(program)
+        if fpath:
+            if is_exe(program):
+                return program
+        else:
+            paths = os.environ["PATH"].split(os.pathsep)
+            if extra_path:
+                paths += extra_path.split(os.pathsep)
 
-    fpath, fname = os.path.split(program)
-    if fpath:
-        if is_exe(program):
-            return program
+            for path in paths:
+                exe_file = os.path.join(path, program)
+                if is_exe(exe_file):
+                    return exe_file
+        return ""
+    if get_host_os() == 'Win32':
+        program_bak = program
+        if program.endswith('.exe') == False:
+            program += '.exe'
+        exe_file = which_internal(program, extra_path)
+        if not exe_file:
+            if program_bak.endswith('.bat') == False:
+                program = program_bak + '.bat'
+            exe_file = which_internal(program, extra_path)
+        return exe_file 
     else:
-        paths = os.environ["PATH"].split(os.pathsep)
-        if extra_path:
-            paths += extra_path.split(os.pathsep)
-
-        for path in paths:
-            exe_file = os.path.join(path, program)
-            if is_exe(exe_file):
-                return exe_file
-    return None
+        return which_internal(program, extra_path)
 
 def get_mem_info(map_file):
     total_ro = 0
@@ -603,13 +612,14 @@ def get_mem_info(map_file):
     print('| %-40s | %-8d  | %-8d |'%('TOTAL (bytes)', total_ro, total_rw))
     print('|=================================================================|')
 
+def getSolutionAndBoard(yoc_path):
+    config_file = os.path.join(yoc_path, ".config")
+    if os.path.isfile(config_file) and os.path.isfile(os.path.join(yoc_path, ".aos")):
+        conf = yaml_load(config_file)
+        return conf["solution"], conf["board"]
+    return None, None
+
 def change_dir_to_solution(yoc_path):
-    def getSolutionAndBoard(yoc_path):
-        config_file = os.path.join(yoc_path, ".config")
-        if os.path.isfile(config_file) and os.path.isfile(os.path.join(yoc_path, ".aos")):
-            conf = yaml_load(config_file)
-            return conf["solution"], conf["board"]
-        return None, None
     cur_dir = os.getcwd()
     # enter into solution directory if in the workspace root directory
     if cur_dir == yoc_path:
@@ -621,7 +631,7 @@ def change_dir_to_solution(yoc_path):
                 put_string("change dir to %s." % new_dir)
     return cur_dir
 
-def check_version_text(lines):
+def check_version_text(current_version, lines):
     text = ""
     pattern = re.compile(r'aos-tools\s+([0-9\.]*)\s+([0-9\.]*)')
     for line in lines:
@@ -636,12 +646,13 @@ def check_version_text(lines):
             match = pattern.search(line)
             if match:
                 text = line
-                put_string("\n\n[NOTICE]The lastest version aos-tools is %s. You can upgrade it as below:" % match.group(2))
-                put_string("python -m pip install -U aos-tools")
+                if current_version != match.group(2):
+                    put_string("\n\n[NOTICE]The lastest version aos-tools is %s. You can upgrade it as below:" % match.group(2))
+                    put_string("python -m pip install -U aos-tools")
                 break
     return text
 
-def check_remote_version():
+def check_remote_version(current_version):
     need_check = False
     ver_file = home_path('.aliot/version')
     if os.path.isfile(ver_file):
@@ -652,7 +663,7 @@ def check_remote_version():
         else:
             with open(ver_file, 'r') as f:
                 lines = f.readlines()
-                check_version_text(lines)
+                check_version_text(current_version, lines)
     else:
         need_check = True
         aliot_dir = home_path('.aliot')
@@ -662,7 +673,7 @@ def check_remote_version():
         put_string("\n\nChecking latest version of aos-tools from pip server...")
         script_process = subprocess.Popen("python -m pip list --outdated", shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
         lines = script_process.stdout.readlines()
-        line = check_version_text(lines)
+        line = check_version_text(current_version, lines)
         if line:
             with open(ver_file, 'w') as f:
                 f.write(line)
